@@ -20,13 +20,15 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-lambda-sqs`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.lambdasqs`|
 
+## Overview
+
 This AWS Solutions Construct implements an AWS Lambda function connected to an Amazon SQS queue.
 
 Here is a minimal deployable pattern definition:
 
 Typescript
 
-```python
+```typescript
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { LambdaToSqs, LambdaToSqsProps } from "@aws-solutions-constructs/aws-lambda-sqs";
@@ -96,7 +98,7 @@ new LambdaToSqs(this, "test-lambda-sqs-stack", new LambdaToSqsProps.Builder()
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon SQS. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
 |vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
-|queueEnvironmentVariableName?|`string`|Optional Name for the SQS queue URL environment variable set for the Lambda function.|
+|queueEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
 
 ## Pattern Properties
 
@@ -135,7 +137,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -152,11 +154,11 @@ from ._jsii import *
 import aws_cdk.aws_ec2
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class LambdaToSqs(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-sqs.LambdaToSqs",
 ):
@@ -166,7 +168,7 @@ class LambdaToSqs(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
@@ -194,7 +196,7 @@ class LambdaToSqs(
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_environment_variable_name: Optional Name for the SQS queue URL environment variable set for the Lambda function. Default: - None
+        :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -285,7 +287,7 @@ class LambdaToSqsProps:
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_environment_variable_name: Optional Name for the SQS queue URL environment variable set for the Lambda function. Default: - None
+        :param queue_environment_variable_name: Optional Name for the Lambda function environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
@@ -407,9 +409,9 @@ class LambdaToSqsProps:
 
     @builtins.property
     def queue_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the SQS queue URL environment variable set for the Lambda function.
+        '''Optional Name for the Lambda function environment variable set to the URL of the queue.
 
-        :default: - None
+        :default: - SQS_QUEUE_URL
         '''
         result = self._values.get("queue_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
